@@ -44,6 +44,9 @@ use oura::sinks::aws_lambda::Config as AwsLambdaConfig;
 #[cfg(feature = "aws")]
 use oura::sinks::aws_s3::Config as AwsS3Config;
 
+#[cfg(feature = "gcp")]
+use oura::sinks::gcp_pubsub::Config as GcpPubSubConfig;
+
 #[cfg(feature = "fingerprint")]
 use oura::filters::fingerprint::Config as FingerprintConfig;
 
@@ -117,6 +120,9 @@ enum Sink {
 
     #[cfg(feature = "aws")]
     AwsS3(AwsS3Config),
+
+    #[cfg(feature = "gcp")]
+    GcpPubSub(GcpPubSubConfig),
 }
 
 fn bootstrap_sink(config: Sink, input: StageReceiver, utils: Arc<Utils>) -> BootstrapResult {
@@ -145,6 +151,9 @@ fn bootstrap_sink(config: Sink, input: StageReceiver, utils: Arc<Utils>) -> Boot
 
         #[cfg(feature = "aws")]
         Sink::AwsS3(c) => WithUtils::new(c, utils).bootstrap(input),
+
+        #[cfg(feature = "gcp")]
+        Sink::GcpPubSub(c) => WithUtils::new(c, utils).bootstrap(input),
     }
 }
 
